# mlapme


## Installation

```
pip install mlapme==0.0.1
```

## depends

numpy == 1.26.4
pandas == 2.2.1

## Usage

null

## Get help

Get help ➡️ [Github issue](https://github.com)

## Update log

`0.0.2` first release

